@@ -188,6 +188,12 @@ class YAMLConfig(ABC):
             if params.typecast is not None and value is not None:
                 value = params.typecast(value)
             out[params.kwarg_alias or name] = value
+        if type(self.sub_configurations) is dict:
+            for sub_config in self.sub_configurations:
+                instance: YAMLConfig = getattr(self, sub_config, None)
+                if instance is None:
+                    continue
+                out.update(**instance.get_current_kwargs())
         return out
 
     def get_full_yaml_string_list(self, **overrides) -> List[str]:
@@ -338,6 +344,14 @@ class YAMLConfig(ABC):
             if params.typecast is not None and value is not None:
                 value = params.typecast(value)
             out[params.kwarg_alias or name] = value
+        if type(cls.sub_configurations) is dict:
+            for attr_name, deriv_class in cls.sub_configurations.items():
+                base_kwargs = deriv_class.get_default_kwargs()
+                if attr_name in cls.sub_configuration_aliases:
+                    for key, alias in cls.sub_configuration_aliases[attr_name].items():
+                        base_kwargs[alias] = base_kwargs[key]
+                        del base_kwargs[key]
+                out.update(**base_kwargs)
         return out
 
     @classmethod
@@ -356,7 +370,10 @@ class YAMLConfig(ABC):
             docstring = cls._get_cls_prop_doc(name) or params.docstring
             if docstring is not None:
                 lines.append(f'# {docstring}')
-            value = overrides.get(name) or params.default_value
+            if name in overrides:
+                value = overrides.get(name)
+            else:
+                value = params.default_value
             if value is not None:
                 value = params.typecast(value) if params.typecast is not None else value
                 # if the value is a string then surround the value with " "
